<?php
/**
 * This is base class for all entities classes in Products.
 * Sets default values for audit columns and nrorg column.
 *
 * @property int       $nrorg
 * @property int       $nrorginclusao
 * @property string    $cdoperinclusao
 * @property \DateTime $dtinclusao
 * @property int       $nrorgultatu
 * @property string    $cdoperultatu
 * @property \DateTime $dtultatu
 */

namespace Geral\Util;

class Entidade extends \Setforms2\Shared\ORM\BasicEntity
{

    public function __construct() {
        $this->nrorg = Ambiente::getNrorg();
        $this->nrorginclusao = Ambiente::getNrorg();
        $this->cdoperinclusao = Ambiente::getCdOperador();
        $this->dtinclusao = DateUtil::getDataAtual();
        parent::__construct();
    }

    public function prePersist()
    {
        $this->nrorgultatu = Ambiente::getNrorg();
        $this->cdoperultatu = Ambiente::getCdOperador();
        $this->dtultatu = DateUtil::getDataAtual();
        parent::preUpdate();
    }

    /**
     * This method sets all the audit fields required in time of inserting
     * new data.
     *
     * @static
     *
     */
    public static function setAuditFieldsBeforeInsert()
    {
        $setOnInsert = array(
            "NRORG"          => Ambiente::getNrorg(),
            "DTINCLUSAO"     => DateUtil::getDataAtual()->format(DateUtil::FORMATO_BRASILEIRO),
            "NRORGINCLUSAO"  => Ambiente::getNrorg(),
            "CDOPERINCLUSAO" => Ambiente::getCdOperador(),
            // List of fields for updating audit, that must also be set in moment of inserting data.
            "DTULTATU"     => DateUtil::getDataAtual()->format(DateUtil::FORMATO_BRASILEIRO),
            "NRORGULTATU"  => Ambiente::getNrorg(),
            "CDOPERULTATU" => Ambiente::getCdOperador(),
        );

        self::execute($setOnInsert);
    }

    /**
     * This method sets all the audit fields required in time of updating data.
     *
     * @static
     *
     */
    public static function setAuditFieldsBeforeUpdate()
    {
        $setOnUpdate = array(
            "DTULTATU"     => DateUtil::getDataAtual(),
            "NRORGULTATU"  => Ambiente::getNrorg(),
            "CDOPERULTATU" => Ambiente::getCdOperador(),
        );

        self::execute($setOnUpdate);
    }

    /**
     * It sets the list of audit fields.
     *
     * @static
     * @param array $dataset
     */
    private static function execute($dataset = array())
    {
        $row = \Setforms2\Runtime\Framework::getInstance()->getCurrentMapper()->getDatasource()->
                                             getMapper()->getCurrentRow();

        foreach ($dataset as $key => $value) {
            if (array_key_exists($key, $row)) {
                $row[$key] = $value;
            }
        }

        \Setforms2\Runtime\Framework::getInstance()->getCurrentMapper()->getDatasource()->
            getMapper()->setCurrentRow($row);
    }
}



